@@ -2,23 +2,23 @@ import os
 import sys
 import spinne
 
-import main
-import index
-import css # TODO: add css support
+from .main import *
+from .index import *
+from .css import * # TODO: add css support
 
-def main(name):
+def new(name):
     print("Creating app...")
     if not os.path.exists(name):
         os.mkdir(name)
     with open(f"{name}/main.py", "w") as f:
-        f.write(main.main)
+        f.write(main)
         print("created main file...")
     with open(f"{name}/index.py", "w") as f:
-        f.write(index.index)
+        f.write(index)
         print("created index...")
 
 try:
     if sys.argv[1] == "--new" or "-n":
-        main(sys.argv[2])
+        new(sys.argv[2])
 except IndexError:
     print("Usage: spinne --new <name>")
\ No newline at end of file
